@@ -115,7 +115,7 @@ my $_is_inflated = sub {
 };
 
 my $_unpack = sub {
-   my ($self, $attr) = @_; $attr ||= {};
+   my ($self, $attr) = @_; $attr //= {};
 
    blessed $self and return ($self, $self->{appclass}, $self->{home});
 
@@ -146,14 +146,16 @@ around 'BUILDARGS' => sub {
 sub _build_appldir {
    my ($self, $appclass, $home) = $_unpack->( @_ ); my $dir;
 
-   if ($dir = home2appldir $home) {
-      $dir = rel2abs( untaint_path $dir );
-      -d catdir( $dir, 'lib' ) and return $dir;
-   }
+   $dir = home2appldir $home
+      and $dir = rel2abs( untaint_path $dir )
+      and -d catdir( $dir, 'lib' ) and return $dir;
+
+   $dir = catdir( NUL, 'var', class2appdir $appclass )
+      and $dir = rel2abs( untaint_path $dir )
+      and -d $dir and return $dir;
+
+   $dir = rel2abs( untaint_path $home ) and -d $dir and return $dir;
 
-   $dir = catdir ( NUL, 'var', class2appdir $appclass );
-   $dir = rel2abs( untaint_path $dir    ); -d $dir and return $dir;
-   $dir = rel2abs( untaint_path $home   ); -d $dir and return $dir;
    return rel2abs( untaint_path rootdir );
 }
 
@@ -297,7 +299,7 @@ sub inflate_path {
 }
 
 sub inflate_paths {
-   my ($self, $attr) = @_; $attr or return;
+   my ($self, $attr) = @_; defined $attr or return;
 
    for my $name (keys %{ $attr }) {
       defined $attr->{ $name }
@@ -309,7 +311,7 @@ sub inflate_paths {
 }
 
 sub inflate_symbol {
-   my ($self, $attr, $symbol) = @_; $attr ||= {}; $symbol or return;
+   my ($self, $attr, $symbol) = @_; $attr //= {}; defined $symbol or return;
 
    my $attr_name = lc $symbol; my $method = "_build_${attr_name}";
 
@@ -563,7 +565,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
