@@ -12,8 +12,10 @@ use Class::Usul::Constants     qw( ASSERT DEFAULT_CONFHOME DEFAULT_ENVDIR
                                    UNTAINT_IDENTIFIER UNTAINT_PATH UUID_PATH );
 use Cwd                        qw( );
 use Data::Printer      alias => q(_data_dumper), colored => 1, indent => 3,
-    filters => { 'File::DataClass::IO' => sub { $_[ 0 ]->pathname },
-                 'JSON::XS::Boolean'   => sub { q().$_[ 0 ]       }, };
+    filters => { 'File::DataClass::IO' => sub { $_[ 0 ]->pathname     },
+                 'JSON::XS::Boolean'   => sub { $_[ 0 ].q()           },
+                 'Type::Tiny'          => sub { $_[ 0 ]->display_name },
+                 'Type::Tiny::Union'   => sub { $_[ 0 ]->display_name }, };
 use Digest                     qw( );
 use Digest::MD5                qw( md5 );
 use English                    qw( -no_match_vars );
@@ -490,9 +492,12 @@ sub find_apphome ($;$$) {
    $path = assert_directory catdir( $path, $appdir ) and return $path;
    # 2b.   Users home directory - dot file containing shell env variable
    $path = $_get_file_var->( $my_home, $app_pref, $classdir ) and return $path;
+   $path = $_get_file_var->( $my_home, $appdir,   $classdir ) and return $path;
    # 2c.   Users home directory - dot directory is apphome
    $path = catdir( $my_home, ".${app_pref}" );
    $path = assert_directory $path and return $path;
+   $path = catdir( $my_home, ".${appdir}" );
+   $path = assert_directory $path and return $path;
    # 3.    Well known path containing shell env file
    $path = $_get_known_file_var->( $appdir, $classdir ) and return $path;
    # 4.    Default install prefix
@@ -1516,7 +1521,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
