@@ -2,12 +2,11 @@ package Class::Usul::Log;
 
 use namespace::autoclean;
 
-use Class::Null;
 use Class::Usul::Constants qw( FALSE LOG_LEVELS NUL SPC TRUE );
 use Class::Usul::Functions qw( is_hashref is_member merge_attributes
                                untaint_identifier );
 use Class::Usul::Types     qw( Bool DataEncoding HashRef
-                               LoadableClass Logger Undef );
+                               LoadableClass Logger SimpleStr Undef );
 use Encode                 qw( encode );
 use File::Basename         qw( dirname );
 use File::DataClass::Types qw( Path );
@@ -15,11 +14,13 @@ use Scalar::Util           qw( blessed );
 use Sub::Install           qw( install_sub );
 use Moo;
 
-# Construction
-my $_build_log = sub {
-   my $self = shift; my $attr = $self->get_log_attributes;
+# Attribute constructors
+my $_build__log = sub {
+   return $_[ 0 ]->_log_class->new( %{ $_[ 0 ]->_log_attributes } );
+};
 
-   return $attr ? $self->_log_class->new( %{ $attr } ) : Class::Null->new;
+my $_build__log_class = sub {
+   return $_[ 0 ]->_logfile ? 'Log::Handler' : 'Class::Null';
 };
 
 # Private attributes
@@ -29,25 +30,28 @@ has '_debug_flag'     => is => 'ro',   isa => Bool, default => FALSE,
 has '_encoding'       => is => 'ro',   isa => DataEncoding | Undef,
    init_arg           => 'encoding';
 
-has '_log'            => is => 'lazy', isa => Logger, builder => $_build_log,
-   init_arg           => 'log';
+has '_log'            => is => 'lazy', isa => Logger,
+   builder            => $_build__log, init_arg => 'log';
 
-has '_log_attributes' => is => 'ro',   isa => HashRef, default => sub { {} },
-   init_arg           => 'log_attributes';
+has '_log_attributes' => is => 'ro',   isa => HashRef,
+   builder            => sub { {} },   init_arg => 'log_attributes';
 
 has '_log_class'      => is => 'lazy', isa => LoadableClass, coerce => TRUE,
-   default            => 'Log::Handler', init_arg => 'log_class';
+   builder            => $_build__log_class, init_arg => 'log_class';
 
 has '_logfile'        => is => 'ro',   isa => Path | Undef, coerce => TRUE,
    init_arg           => 'logfile';
 
+# Private class attributes
+my $loggers = {};
+
 # Construction
 around 'BUILDARGS' => sub {
    my ($orig, $class, @args) = @_; my $attr = $orig->( $class, @args );
 
    my $builder = delete $attr->{builder} or return $attr;
    my $config  = $builder->can( 'config' ) ? $builder->config : {};
-   my $cfgattr = [ qw( encoding log_attributes log_class logfile ) ];
+   my $cfgattr = [ qw( appclass encoding log_attributes log_class logfile ) ];
 
    merge_attributes $attr, $builder, {}, [ 'debug' ];
    merge_attributes $attr, $config,  {}, $cfgattr;
@@ -55,47 +59,34 @@ around 'BUILDARGS' => sub {
    return $attr;
 };
 
-my $_add_methods = sub {
-   my ($class, @methods) = @_;
+sub BUILD {
+   my ($self, $attr) = @_;
 
-   for my $method (@methods) {
-      $class->can( $method )
-         or install_sub { into => $class, as => $method, code => sub {
-            my ($self, $text, $opts) = @_; $text or return FALSE;
-
-            $text = ucfirst "${text}"; chomp $text; $text .= "\n";
-
-            if (defined $opts) {
-               my $lead = ucfirst $opts->{leader} // NUL;
-               my $user = $opts->{user} ? '['.$opts->{user}->username.'] '
-                        :         $lead ? SPC
-                                        : NUL;
-
-               $text = "${lead}${user}${text}";
-            }
-
-            $self->_encoding and $text = encode( $self->_encoding, $text );
-            $self->_log->$method( $text );
-            return TRUE;
-         } };
-   }
+   exists $attr->{appclass}  and $loggers->{ $attr->{appclass} } = $self;
+   exists $loggers->{default} or $loggers->{default} = $self;
 
    return;
-};
-
-$_add_methods->( __PACKAGE__, LOG_LEVELS );
-
-# Public methods
-sub filehandle {
-   my $self = shift; $self->_log_class eq 'Log::Handler' or return;
-
-   return $self->_log->output( 'file-out' )->{fh};
 }
 
-sub get_log_attributes {
-   my $self = shift; my $attr = { %{ $self->_log_attributes } };
+sub import {
+   my $class  = shift;
+   my $params = { (is_hashref $_[ 0 ]) ? %{+ shift } : () };
+   my @wanted = @_;
+   my $target = caller;
+   my $subr   = $params->{as} // 'log';
 
-   $self->_log_class eq 'Log::Handler' or return $attr;
+   $wanted[ 0 ] and
+      install_sub { into => $target, as => $subr, code => sub (;@) {
+         return $loggers->{ $wanted[ 0 ] }->log( @_ );
+      } };
+
+   return;
+}
+
+around '_log_attributes' => sub {
+   my ($orig, $self) = @_; my $attr = $orig->( $self );
+
+   $self->_log_class ne 'Log::Handler' and return $attr;
 
    my $fattr   = $attr->{file} //= {};
    my $logfile = $fattr->{filename} // $self->_logfile;
@@ -107,18 +98,68 @@ sub get_log_attributes {
    $fattr->{maxlevel} = $self->_debug_flag ? 'debug'
                       : untaint_identifier $fattr->{maxlevel} // 'info';
    $fattr->{mode    } = untaint_identifier $fattr->{mode    } // 'append';
+
    return $attr;
+};
+
+# Private functions
+my $add_methods = sub {
+   my ($class, @methods) = @_;
+
+   for my $method (@methods) {
+      $class->can( $method ) or
+         install_sub { into => $class, as => $method, code => sub {
+            my ($self, $text, $opts) = @_; $text or return FALSE;
+
+            $text = ucfirst "${text}"; chomp $text; $text .= "\n";
+
+            if (defined $opts) {
+               my $lead = ucfirst $opts->{leader} // NUL;
+               my $tag  = $opts->{tag}
+                      // ($opts->{user} ? $opts->{user}->username : NUL);
+
+               $tag  = $tag ? "[${tag}] " : $lead ? SPC : NUL;
+               $text = "${lead}${tag}${text}";
+            }
+
+            $self->_encoding and $text = encode( $self->_encoding, $text );
+            $self->_log->$method( $text );
+            return TRUE;
+         } };
+   }
+
+   return;
+};
+
+$add_methods->( __PACKAGE__, LOG_LEVELS );
+
+my @arg_names = qw( level message options );
+
+my $inline_args = sub {
+   my $n = shift; return (map { $arg_names[ $_ ] => $_[ $_ ] } 0 .. $n - 1);
+};
+
+# Public methods
+sub filehandle {
+   my $self = shift; $self->_log_class ne 'Log::Handler' and return;
+
+   return $self->_log->output( 'file-out' )->{fh};
 }
 
 sub log {
-   my ($self, @args) = @_;
+   my ($self, @args) = @_; my $n = 0; $n++ while (defined $args[ $n ]);
 
-   my $args  = (is_hashref $args[ 0 ]) ? $args[ 0 ] : { @args };
-   my $level = $args->{level};
+   my $args  = ($n == 0              ) ? {}
+             : (is_hashref $args[ 0 ]) ? $args[ 0 ]
+             : ($n == 1              ) ? { $inline_args->( 2, 'info', @args ) }
+             : ($n == 2              ) ? { $inline_args->( 2, @args ) }
+             : ($n == 3              ) ? { $inline_args->( 3, @args ) }
+             :                           { @args };
 
-   is_member $level, LOG_LEVELS and return $self->$level( $args->{message} );
+   my $level = $args->{level}; $level and is_member $level, LOG_LEVELS
+      and return $self->$level( $args->{message}, $args->{options} );
 
-   return;
+   return FALSE;
 }
 
 1;
@@ -127,6 +168,8 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 Name
 
 Class::Usul::Log - Create methods for each logging level that encode their output
@@ -194,16 +237,15 @@ Path to the logfile
 
 Monkey with the constructors signature
 
+=head2 C<BUILD>
+
+Store the new object reference in a class attribute for later importation
+
 =head2 C<filehandle>
 
 Return the loggers file handle. This was added for L<IO::Async>, so that we
 can tell it not to close the log file handle when it forks a child process
 
-=head2 C<get_log_attributes>
-
-Returns the hash reference passed to the constructor of the log class. Returns
-C<undef> to indicate no logging, an instance of L<Class::Null> is used instead
-
 =head2 C<log>
 
    $self->log( { level => $level, message => $message } );
@@ -250,7 +292,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
